@@ -1,9 +1,11 @@
+use quote::ToTokens;
 use syn::{Attribute, Expr};
 
 pub struct FieldAttributes {
     pub default: Option<Expr>,
     pub use_into: bool,
     pub validator: Option<Expr>,
+    pub documents: Vec<Attribute>,
 }
 
 impl Default for FieldAttributes {
@@ -12,6 +14,7 @@ impl Default for FieldAttributes {
             default: None,
             use_into: false,
             validator: None,
+            documents: vec![],
         }
     }
 }
@@ -29,6 +32,8 @@ impl From<Vec<Attribute>> for FieldAttributes {
                 attributes.use_into = true
             } else if attr.path.is_ident("validator") {
                 parse_validator(attr, &mut attributes)
+            } else if attr.path.is_ident("doc") {
+                attributes.documents = get_documents(&attrs);
             }
         });
         attributes
@@ -42,3 +47,17 @@ fn parse_default(attr: &Attribute, attributes: &mut FieldAttributes) {
 fn parse_validator(attr: &Attribute, attributes: &mut FieldAttributes) {
     attributes.validator = Some(attr.parse_args().unwrap());
 }
+
+pub fn get_documents(attrs: &[Attribute]) -> Vec<Attribute> {
+    let mut documents: Vec<Attribute> = vec![];
+
+    for attr in attrs {
+        if attr.path.is_ident("doc") {
+            documents.push(attr.to_owned());
+            println!("{}", attr.to_token_stream());
+        }
+    }
+    println!();
+
+    documents
+}
